pub enum SymmetricCryptoKey {
Aes256CbcKey(Aes256CbcKey),
Aes256CbcHmacKey(Aes256CbcHmacKey),
XChaCha20Poly1305Key(XChaCha20Poly1305Key),
Aes256GcmKey(Aes256GcmKey),
XAes256GcmKey(XAes256GcmKey),
}Expand description
A symmetric encryption key. Used to encrypt and decrypt EncString
Variants
Aes256CbcKey(Aes256CbcKey)
Aes256CbcHmacKey(Aes256CbcHmacKey)
XChaCha20Poly1305Key(XChaCha20Poly1305Key)
Data encrypted by XChaCha20Poly1305Key keys has type
Cose_Encrypt0_B64
Aes256GcmKey(Aes256GcmKey)
FIPS-approved AES-256-GCM key, used as the content-encryption key for FIPS
DataEnvelopes. Encoded as a COSE key.
XAes256GcmKey(XAes256GcmKey)
Extended-nonce AES-256-GCM key. Encoded as a COSE key and used with type-7 EncStrings.
Implementations
Sourceimpl SymmetricCryptoKey
impl SymmetricCryptoKey
const AES256_CBC_KEY_LEN: usize = 32
const AES256_CBC_HMAC_KEY_LEN: usize = 64
Sourcepub(crate) fn make_aes256_cbc_hmac_key_internal(rng: impl CryptoRng) -> Self
pub(crate) fn make_aes256_cbc_hmac_key_internal(rng: impl CryptoRng) -> Self
Generate a new random AES256_CBC SymmetricCryptoKey
WARNING: This function should only be used with a proper cryptographic RNG. If you do not have a good reason for using this function, use SymmetricCryptoKey::make_aes256_cbc_hmac_key instead.
Sourcepub fn make(algorithm: SymmetricKeyAlgorithm) -> Self
pub fn make(algorithm: SymmetricKeyAlgorithm) -> Self
Make a new SymmetricCryptoKey for the specified algorithm
Sourcepub(crate) fn make_aes256_cbc_hmac_key() -> Self
pub(crate) fn make_aes256_cbc_hmac_key() -> Self
Generate a new random AES256_CBC_HMAC SymmetricCryptoKey
Sourcepub(crate) fn make_xchacha20_poly1305_key() -> Self
pub(crate) fn make_xchacha20_poly1305_key() -> Self
Generate a new random XChaCha20Poly1305 SymmetricCryptoKey
Sourcepub fn to_encoded(&self) -> BitwardenLegacyKeyBytes
pub fn to_encoded(&self) -> BitwardenLegacyKeyBytes
Encodes the key to a byte array representation, that is separated by size. SymmetricCryptoKey::Aes256CbcHmacKey and SymmetricCryptoKey::Aes256CbcKey are encoded as 64 and 32 bytes respectively. COSE-serialized variants are encoded as at least 65 bytes using padding.
This can be used for storage and transmission in the old byte array format. When the wrapping key is a COSE key, and the wrapped key is a COSE key, then this should not use the byte representation but instead use the COSE key representation.
Sourcepub(crate) fn to_encoded_raw(&self) -> EncodedSymmetricKey
pub(crate) fn to_encoded_raw(&self) -> EncodedSymmetricKey
Creates the byte representation of the key, without any padding. This should not be used directly for creating serialized key representations, instead, SymmetricCryptoKey::to_encoded should be used.
SymmetricCryptoKey::Aes256CbcHmacKey and SymmetricCryptoKey::Aes256CbcKey are encoded as 64 and 32 byte arrays respectively, representing the key bytes directly. XChaCha20-Poly1305, AES-256-GCM, and XAES-256-GCM keys are encoded as serialized COSE keys. A COSE key can be directly encrypted with a COSE key content format or represented as a byte array. When represented as a byte array, the array is padded to be larger than the byte array representation of the other aforementioned key types.
pub(crate) fn try_from_cose(serialized_key: &[u8]) -> Result<Self, CryptoError>
pub fn to_base64(&self) -> B64
Sourcepub fn key_id(&self) -> Option<KeyId>
pub fn key_id(&self) -> Option<KeyId>
Returns the key ID of the key, if it has one. COSE-serialized key variants have a key ID.
Sourcepub(crate) fn as_cose_key_view(&self) -> Option<CoseKeyView<'_>>
pub(crate) fn as_cose_key_view(&self) -> Option<CoseKeyView<'_>>
Returns a CoseKeyView for COSE-encoded symmetric key variants.
Legacy AES-CBC variants return None.