pub struct Aes256GcmKey {
pub(crate) key_id: KeyId,
pub(crate) enc_key: Pin<Box<Array<u8, U32>>>,
pub(crate) supported_operations: Vec<KeyOperation>,
}Expand description
Aes256GcmKey is a symmetric AEAD key consisting of one 256-bit key
Fields
key_id: KeyIdenc_key: Pin<Box<Array<u8, U32>>>supported_operations: Vec<KeyOperation>Controls which key operations are allowed with this key. See
XChaCha20Poly1305Key::supported_operations.
Implementations
Sourceimpl Aes256GcmKey
impl Aes256GcmKey
Sourcepub fn make() -> Self
pub fn make() -> Self
Creates a new Aes256GcmKey with a securely sampled cryptographic key and key id.
pub(crate) fn disable_key_operation(&mut self, op: KeyOperation) -> &mut Self