pub struct SignedObject(pub(crate) CoseSign1);Expand description
A signed object is a message containing a payload and signature that attests the payload’s integrity and authenticity for a specific namespace and signature key. In order to gain access to the payload, the caller must provide the correct namespace and verifying key, ensuring that the caller cannot forget to validate the signature before using the payload.
Tuple Fields
0: CoseSign1Implementations
Sourceimpl SignedObject
impl SignedObject
Sourcepub fn content_type(&self) -> Result<CoapContentFormat, CryptoError>
pub fn content_type(&self) -> Result<CoapContentFormat, CryptoError>
Parses the signature headers and returns the content type of the signed data. The content type indicates how the serialized message that was signed was encoded.
Sourcepub fn signed_by_id(&self) -> Result<KeyId, CryptoError>
pub fn signed_by_id(&self) -> Result<KeyId, CryptoError>
Returns the signing key ID from the COSE protected header.
fn inner(&self) -> &CoseSign1
fn namespace(&self) -> Result<SigningNamespace, CryptoError>
fn payload(&self) -> Result<Vec<u8>, CryptoError>
Sourcepub fn verify_and_unwrap<Message: DeserializeOwned>(
&self,
verifying_key: &VerifyingKey,
namespace: &SigningNamespace,
) -> Result<Message, CryptoError>
pub fn verify_and_unwrap<Message: DeserializeOwned>( &self, verifying_key: &VerifyingKey, namespace: &SigningNamespace, ) -> Result<Message, CryptoError>
Verifies the signature of the signed object and returns the payload, if the signature is valid.
Sourcefn verify_and_unwrap_bytes(
&self,
verifying_key: &VerifyingKey,
namespace: &SigningNamespace,
) -> Result<Vec<u8>, CryptoError>
fn verify_and_unwrap_bytes( &self, verifying_key: &VerifyingKey, namespace: &SigningNamespace, ) -> Result<Vec<u8>, CryptoError>
Verifies the signature of the signed object and returns the payload as raw bytes, if the signature is valid.