KeySlotIds

Trait KeySlotIds 

pub trait KeySlotIds {
    type Symmetric: KeySlotId<KeyValue = SymmetricCryptoKey>;
    type Private: KeySlotId<KeyValue = PrivateKey>;
    type Signing: KeySlotId<KeyValue = SigningKey>;
}
Represents a set of all the key identifiers that need to be defined to use a key store.

Required Associated Types

type Symmetric: KeySlotId<KeyValue = SymmetricCryptoKey>

type Private: KeySlotId<KeyValue = PrivateKey>

type Signing: KeySlotId<KeyValue = SigningKey>

Signing keys are used to create detached signatures and to sign objects.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors